##  Step 4: Connect Tech Platforms with Applications
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2742d1a67a441014a6d8ea3b24446315_LowRes.png)
**Note**
It is possible to have more than one platform per application.
